@@ -5,12 +5,9 @@ use warnings;
 use 5.008001;
 use base qw(Alien::Base);
 
-our $VERSION = '2.03_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '2.01'; # VERSION
 # ABSTRACT: Build and install libyaml, a C-based YAML parser and emitter
 
-
-
 1;
 
 __END__
@@ -25,42 +22,21 @@ Alien::LibYAML - Build and install libyaml, a C-based YAML parser and emitter
 
 =head1 VERSION
 
-version 2.03_01
+version 2.01
 
 =head1 SYNOPSIS
 
-In your Build.PL:
+In your C<Build.PL>:
 
- use Module::Build;
- use Alien::LibYAML;
- my $builder = Module::Build->new(
-   ...
-   configure_requires => {
-     'Alien::LibYAML' => '0',
-     ...
-   },
-   extra_compiler_flags => Alien::LibYAML->cflags,
-   extra_linker_flags   => Alien::LibYAML->libs,
-   ...
- );
- 
- $build->create_build_script;
-
-In your Makefile.PL:
-
- use ExtUtils::MakeMaker;
- use Config;
- use Alien::LibYAML;
- 
- WriteMakefile(
-   ...
-   CONFIGURE_REQUIRES => {
-     'Alien::LibYAML' => '0',
-   },
-   CCFLAGS => Alien::LibYAML->cflags . " $Config{ccflags}",
-   LIBS    => [ Alien::LibYAML->libs ],
-   ...
- );
+    use Alien::LibYAML;
+    use Module::Build;
+    
+    Module::Build->new(
+      ...
+      extra_compiler_flags => Alien::LibYAML->cflags,
+      extra_linker_flags   => Alien::LibYAML->libs,
+      ...
+    )->create_build_script;
 
 =head1 DESCRIPTION
 
@@ -84,15 +60,23 @@ Simonov. Both libyaml and this distribution are released under the terms of the
 B<MIT License> and may be modified and/or redistributed under the same or any
 compatible license.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Original author: Richard Simões (RSIMOES)
+=over 4
 
-Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+=item *
+
+Richard Simões <rsimoes AT cpan DOT org>
+
+=item *
+
+Graham Ollis <plicease@cpan.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013-2018 by Richard Simões.
+This software is Copyright (c) 2017 by Richard Simões.
 
 This is free software, licensed under:
 
